@@ -1,7 +1,7 @@
 package Perinci::Examples::Stream;
 
-our $DATE = '2016-01-19'; # DATE
-our $VERSION = '0.64'; # VERSION
+our $DATE = '2016-01-20'; # DATE
+our $VERSION = '0.65'; # VERSION
 
 use 5.010;
 use strict;
@@ -171,7 +171,7 @@ $SPEC{wc} = {
         },
     },
     result => {
-        schema => 'str*',
+        schema => 'hash*',
     },
 };
 sub wc {
@@ -205,7 +205,7 @@ _
         },
     },
     result => {
-        schema => 'str*',
+        schema => 'hash*',
     },
 };
 sub wc_keys {
@@ -234,7 +234,7 @@ Perinci::Examples::Stream - Examples for streaming input/output
 
 =head1 VERSION
 
-This document describes version 0.64 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2016-01-19.
+This document describes version 0.65 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2016-01-20.
 
 =head1 DESCRIPTION
 
@@ -425,7 +425,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-Return value:  (str)
+Return value:  (hash)
 
 
 =head2 wc_keys(%args) -> [status, msg, result, meta]
@@ -454,7 +454,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-Return value:  (str)
+Return value:  (hash)
 
 =head1 HOMEPAGE
 
